@@ -27,7 +27,7 @@ from . import lookups as filter_lookups
 from . import plugins
 from .common import LimitedJsonApiPageNumberPagination, JsonApiSearchFilter, LOGGER
 from .constructors import _construct_serializer, _construct_filter_backend
-from .json_api_spec_http_methods import HTTP_GET, HTTP_POST, HTTP_PATCH
+from .json_api_spec_http_methods import HTTP_GET, HTTP_POST, HTTP_PATCH, HTTP_DELETE
 from .namespace import _append_to_namespace, _RESOURCE_NAME_TO_SPICE, _MODEL_TO_SERIALIZERS
 from .types import CustomField, Filter, Relation, GenericRelation, ComputedFilter, RelatedResource
 
@@ -59,7 +59,7 @@ def get_dict_by_methods(view_type, allowed_http_methods):
             out['get'] = 'retrieve'
         if HTTP_PATCH in allowed_http_methods:
             out['patch'] = 'update'
-        if HTTP_PATCH in allowed_http_methods:
+        if HTTP_DELETE in allowed_http_methods:
             out['delete'] = 'destroy'
     elif view_type == 'list':
         if HTTP_GET in allowed_http_methods:
@@ -85,7 +85,8 @@ class JsonApiModelViewBuilder:
                  queryset: Optional[QuerySet] = None,
                  permitted_objects: Optional[Callable[[Request, QuerySet], QuerySet]] = None,
                  include_plugins: Optional[Sequence[str]] = None,
-                 plugin_options: Optional[Dict[str, Any]] = None):
+                 plugin_options: Optional[Dict[str, Any]] = None,
+                 expose_related_views: Optional[bool] = False):
         self.__validate_http_methods(allowed_methods)
         self._model = model
         self._fields = {}
@@ -112,6 +113,7 @@ class JsonApiModelViewBuilder:
         self._before_list_callback = None
         self._after_list_callback = None
         self._before_raw_response = None
+        self._expose_related_views = expose_related_views
         self._is_admin = False
         if queryset is None:
             self._queryset = self._model.objects
@@ -308,7 +310,6 @@ class JsonApiModelViewBuilder:
         if plugins.AUTO_ADMIN_VIEWS in self._include_plugins:
             admin_builder._include_plugins = []
         admin_builder._spice_queryset = None
-        admin_builder._resource_name = f'{admin_builder._resource_name}'
         admin_permission_class = admin_builder._plugin_options.get(plugins.AUTO_ADMIN_VIEWS, {}).get(
             'ADMIN_PERMISSION_CLASS')
         admin_builder._is_admin = True
@@ -515,25 +516,28 @@ class JsonApiModelViewBuilder:
 
             urls.extend([
                 url(rf'^{urls_prefix}{url_resource_name}$',
-                    list_method_view_set.as_view(get_dict_by_methods('list', self._allowed_methods), name=f'list_{self._resource_name}'),
+                    list_method_view_set.as_view(get_dict_by_methods('list', self._allowed_methods),
+                                                 name=f'list_{self._resource_name}'),
                     name=f'list-{self._resource_name}{self._api_version}'),
                 url(rf'^{urls_prefix}{url_resource_name}/(?P<{pk_name}>[^/.]+)/$',
                     get_method_view_set.as_view(get_dict_by_methods('get', self._allowed_methods),
                                                 name=f'get_{self._resource_name}'),
                     name=f'{self._resource_name}{self._api_version}-detail'),
-                url(
-                    rf'^{urls_prefix}{url_resource_name}/(?P<{pk_name}>[^/.]+)/relationships/(?P<related_field>[^/.]+)$',
-                    view=relationship_view.as_view(),
-                    name=f'{self._resource_name}{self._api_version}-relationships'),
             ])
 
-            relation_view_dict = get_dict_by_methods('relation', self._allowed_methods)
-            if relation_view_dict:
+            if self._expose_related_views:
                 urls.extend([
-                    url(rf'^{urls_prefix}{url_resource_name}/(?P<{pk_name}>[^/.]+)/(?P<related_field>\w+)/$',
-                        list_method_view_set.as_view(relation_view_dict, name=f'related_{self._resource_name}'),
-                        name=f'related-{self._resource_name}{self._api_version}')
-                ])
+                    url(
+                        rf'^{urls_prefix}{url_resource_name}/(?P<{pk_name}>[^/.]+)/relationships/(?P<related_field>[^/.]+)$',
+                        view=relationship_view.as_view(),
+                        name=f'{self._resource_name}{self._api_version}-relationships')])
+                relation_view_dict = get_dict_by_methods('relation', self._allowed_methods)
+                if relation_view_dict:
+                    urls.extend([
+                        url(rf'^{urls_prefix}{url_resource_name}/(?P<{pk_name}>[^/.]+)/(?P<related_field>\w+)/$',
+                            list_method_view_set.as_view(relation_view_dict, name=f'related_{self._resource_name}'),
+                            name=f'related-{self._resource_name}{self._api_version}')
+                    ])
 
         if plugins.DJANGO_SIMPLE_HISTORY in self._include_plugins:
             try:
@@ -766,7 +770,8 @@ class JsonApiResourceViewBuilder:
         if get_view_set is not None:
             urls.extend([
                 url(rf'^{urls_prefix}{url_resource_name}{urls_suffix}$',
-                    get_view_set.as_view(get_dict_by_methods('list', self._allowed_methods), name=f'list_{self._resource_name}'),
+                    get_view_set.as_view(get_dict_by_methods('list', self._allowed_methods),
+                                         name=f'list_{self._resource_name}'),
                     name=f'list-{self._resource_name}{self._api_version}')
             ])
         if patch_view_set is not None:
